==> Spec-Recorder%20Ver.1.1.zip: Spec-Recorder Ver.1.1/freq_exec.py <==
# -*- coding: utf-8 -*-
import subprocess
import datetime
import time
import sys

def rec(filename):
	subprocess.Popen(['sox', "-d", '-c', '1', "./MP3/" + filename, 'trim', '0', '05:00'])
	#output = subprocess.call(['ping', 'google.com'], shell=1)
	print "Recording start"
	return()

now_minute = int(datetime.datetime.now().strftime("%M"))
now_hour = int(datetime.datetime.now().strftime("%H"))
now_month = int(datetime.datetime.now().strftime("%m"))
now_day = int(datetime.datetime.now().strftime("%d"))
now_year = int(datetime.datetime.now().strftime("%Y"))

#wait_time = sys.argv[1]
#print wait_time

while 1==1:
	if int(datetime.datetime.now().strftime("%M")) % 5 == 0:
		start_year = str(datetime.datetime.now().strftime("%Y"))[2:]
		start_month = str(datetime.datetime.now().strftime("%m"))[:]
		if start_month < 10:
			start_month = "0" + str(datetime.datetime.now().strftime("%m"))[:]
		start_day = str(datetime.datetime.now().strftime("%d"))[:]
		if start_day < 10:
			start_day = "0" + str(datetime.datetime.now().strftime("%d"))[:]
		start_hour = str(datetime.datetime.now().strftime("%H"))[:]
		if start_hour < 10:
			start_hour = "0" + str(datetime.datetime.now().strftime("%H"))[:]
		start_minute = str(datetime.datetime.now().strftime("%M"))[:]
		if datetime.datetime.now().strftime("%M") < 9:
			start_minute = "0" + str(datetime.datetime.now().strftime("%M"))[:]
		filename = str(start_year)[:] + str(start_month)[:] + str(start_day)[:] + str(start_hour)[:] + str(start_minute)[:]
		print "Filename is " + filename + ".mp3"
		#time.sleep(wait_time*0.01)
		time.sleep(0.01)
		rec(filename + ".mp3")
		time.sleep(70)
	time.sleep(0.001)

==> Spec-Recorder%20Ver.1.11.zip: Spec-Recorder Ver.1.11/freq_exec.py <==
# -*- coding: utf-8 -*-
import subprocess
import datetime
import time
import sys

def rec(filename):
	subprocess.Popen(['sox', "-d", '-c', '1', "./ogg/" + filename, 'trim', '0', '05:00'])
	#output = subprocess.call(['ping', 'google.com'], shell=1)
	print "Recording start"
	return()

now_minute = int(datetime.datetime.now().strftime("%M"))
now_hour = int(datetime.datetime.now().strftime("%H"))
now_month = int(datetime.datetime.now().strftime("%m"))
now_day = int(datetime.datetime.now().strftime("%d"))
now_year = int(datetime.datetime.now().strftime("%Y"))

#wait_time = sys.argv[1]
#print wait_time

while 1==1:
	if int(datetime.datetime.now().strftime("%M")) % 5 == 0:
		start_year = str(datetime.datetime.now().strftime("%Y"))[2:]
		start_month = str(datetime.datetime.now().strftime("%m"))[:]
		if start_month < 10:
			start_month = "0" + str(datetime.datetime.now().strftime("%m"))[:]
		start_day = str(datetime.datetime.now().strftime("%d"))[:]
		if start_day < 10:
			start_day = "0" + str(datetime.datetime.now().strftime("%d"))[:]
		start_hour = str(datetime.datetime.now().strftime("%H"))[:]
		if start_hour < 10:
			start_hour = "0" + str(datetime.datetime.now().strftime("%H"))[:]
		start_minute = str(datetime.datetime.now().strftime("%M"))[:]
		if datetime.datetime.now().strftime("%M") < 9:
			start_minute = "0" + str(datetime.datetime.now().strftime("%M"))[:]
		filename = str(start_year)[:] + str(start_month)[:] + str(start_day)[:] + str(start_hour)[:] + str(start_minute)[:]
		print "Filename is " + filename + ".ogg"
		#time.sleep(wait_time*0.01)
		time.sleep(0.01)
		rec(filename + ".ogg")
		time.sleep(70)
	time.sleep(0.001)
